@@ -1,15 +1,10 @@
 // rentries.c: Register native routines for R.
-//             The core of this routine is the function R_init_earth.
+//             The core of this file is the function R_init_earth.
 
 #define USING_R 1
 #include "R.h"
 #include "Rinternals.h" // for REALSXP etc.
 #include "R_ext/Rdynload.h"
-#ifndef _MSC_VER // microsoft
-#ifndef bool
-    typedef int bool;
-#endif
-#endif
 #include "earth.h"
 
 static R_NativePrimitiveArgType FreeEarth_t[] = {INTSXP};
@@ -35,8 +30,9 @@ static R_NativePrimitiveArgType RegressR_t[] = {
     INTSXP,     // 09 const int*   pnCases
     INTSXP,     // 10 const int*   pnResp
     INTSXP,     // 11 int*         pnCols
-    LGLSXP      // 12 const bool   UsedCols[]
+    LGLSXP      // 12 const int    UsedColsR[], assume R LOGICAL is stored as int
 };
+// TODO: for below, "gcc --pedantic" gives "warning: cast between incompatible function types"
 static R_CMethodDef cEntries[] = {
   {"FreeEarth",            (DL_FUNC)&FreeEarth,             0, FreeEarth_t},
   {"EvalSubsetsUsingXtxR", (DL_FUNC)&EvalSubsetsUsingXtxR,  8, EvalSubsetsUsingXtxR_t},
@@ -153,7 +149,8 @@ extern void F77_SUB(sing)(
     double *THETAB,
     double *SSERR,
     double *TOL,
-    bool   *LINDEP,
+// nov 2019: changed LINDEP to int (from bool) to pacify R CRAN check
+    int    *LINDEP,
     double *WORK,
     int    *IER);
 extern void F77_SUB(ssleaps)(
@@ -293,7 +290,8 @@ static R_NativePrimitiveArgType sing_t[] = {
     REALSXP,    // 06 DOUBLE  THETAB
     REALSXP,    // 07 DOUBLE  SSERR
     REALSXP,    // 08 DOUBLE  TOL
-    LGLSXP,     // 10 LOGICAL LINDEP
+// nov 2019: changed LINDEP to INTSXP (from LGLSXP) to pacify R CRAN check
+    INTSXP,     // 10 INTEGER LINDEP
     REALSXP,    // 09 DOUBLE  WORK
     INTSXP,     // 03 INTEGER IER
 };
